==> lddk-0.1a9.tar.gz: lddk/ddl/main.c <==
#include <stdio.h>
#include <getopt.h>
#include <sys/param.h>

extern char *pfile;
extern void usage();

main(int argc,char **argv)
{
  int c;
  extern char template_path[];
  extern char include_path[];
  char pathbuf[MAXPATHLEN];

  init_states();
  while(1){
             int this_option_optind = optind ? optind : 1;
             int option_index = 0;
             static struct option long_options[] =
             {
               {"templates", 1, 0, 0},
               {"includes",  1, 0, 0},
	       {"help",      0, 0, 0},
               {0, 0, 0, 0}
             };

             c = getopt_long (argc, argv, "I:T:",
                        long_options, &option_index);

	     switch(c){
	     case 0:
	       switch( option_index ){
	       case 0:
		 strcpy( template_path ,optarg );
		 break;
	       case 1:
		 strcat( include_path ,":" );
                 strcat( include_path , optarg );
		 /*printf("Adding include %s \n",include_path);*/
		 break;
	       case 2:
		 usage();
		 break;
	       default:
		 exit(1);
		 break;
	       }
              break;
	     case 'T':
		 strcpy( template_path ,optarg );
		 break;
             case 'I':
		 strcat( include_path ,":" );
                 strcat( include_path , optarg );
	       break;
             case '?':
               usage();
               break;

             default:
	       /*printf ("?? getopt returned character code 0%o ??0",c);*/
	       break;

	      }

             if (c == -1)
             break;
  }
             if (optind < argc)
             {
	       extern FILE *yyin;
               char *s; 
               while (optind < argc) {
		 s = argv[optind++];
		 if(( yyin = fopen( s ,"r" )) == NULL ){
		   printf("Can't open input %s \n",s);
		   exit(1);
		 }
                 pfile = s;  
                 init_main();
                 yyparse();
		 fclose(yyin);
	       }

             }
             else {
	       printf("No input files! \n");usage();
	       exit(1);
	     }
  

  exit(0);
}


void usage(){

fprintf(stderr,"\
 DDL -> C Compiler (C)1996 Claus Schroeter (clausi@chemie.fu-berlin.de) \n\
 Usage:\n\
   ddl2c [options] ddlfile\n\
 Options:\n\
  --templates, -T     set template path\n\
  --includes,  -I     add include path\n\
  --help,      -?     display this message\n\
");
}

==> lddk-0.2.tar.gz: lddk/ddl/main.c <==
#include <stdio.h>
#include <getopt.h>
#include <sys/param.h>

extern char *pfile;
extern void usage();

main(int argc,char **argv)
{
  int c;
  extern int noline;
  extern char template_path[];
  extern char include_path[];
  char pathbuf[MAXPATHLEN];

  init_states();
  while(1){
             int this_option_optind = optind ? optind : 1;
             int option_index = 0;
             static struct option long_options[] =
             {
               {"templates", 1, 0, 0},
               {"includes",  1, 0, 0},
	       {"help",      0, 0, 0},
	       {"noline",    0, 0, 0},
               {0, 0, 0, 0}
             };

             c = getopt_long (argc, argv, "lI:T:",
                        long_options, &option_index);

	     switch(c){
	     case 0:
	       switch( option_index ){
	       case 0:
		 strcpy( template_path ,optarg );
		 break;
	       case 1:
		 strcat( include_path ,":" );
                 strcat( include_path , optarg );
		 /*printf("Adding include %s \n",include_path);*/
		 break;
	       case 2:
		 usage();
		 break;
	       case 3:
		 noline = 1;
		 break;
	       default:
		 exit(1);
		 break;
	       }
              break;
	     case 'T':
		 strcpy( template_path ,optarg );
		 break;
             case 'I':
		 strcat( include_path ,":" );
                 strcat( include_path , optarg );
	       break;
	     case 'l':
	       noline = 1;
	       break;
             case '?':
               usage();
               break;

             default:
	       /*printf ("?? getopt returned character code 0%o ??0",c);*/
	       break;

	      }

             if (c == -1)
             break;
  }
             if (optind < argc)
             {
	       extern FILE *yyin;
               char *s; 
               while (optind < argc) {
		 s = argv[optind++];
		 if(( yyin = fopen( s ,"r" )) == NULL ){
		   printf("Can't open input %s \n",s);
		   exit(1);
		 }
                 pfile = s;  
                 init_main();
                 yyparse();
		 fclose(yyin);
	       }

             }
             else {
	       printf("No input files! \n");usage();
	       exit(1);
	     }
  

  exit(0);
}


void usage(){

fprintf(stderr,"\
 DDL -> C Compiler (C)1996 Claus Schroeter (clausi@chemie.fu-berlin.de) \n\
 Usage:\n\
   ddl2c [options] ddlfile\n\
 Options:\n\
  --templates, -T     set template path\n\
  --includes,  -I     add include path\n\
  --noline,    -l     generate without #line directives\n\
  --help,      -?     display this message\n\
");
}
